<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/index6.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:41:22 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEO - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo4.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage4-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader preloader3">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader3.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header>
    <div class="header-area homepage4 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo5.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu auhtor-tabpane">
                      <div class="row">
                        <div class="col-lg-12">
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn12" href="index.html" target="_blank">Multi Page</a>
                                    <div class="space16"></div>
                                    <a class="header-btn12" href="single-index1.html" target="_blank">One Page</a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="404.html">SEO & Digital Marketing 01</a>
                                 </div>
                                 <div class="space20"></div>
                              </div>
                            </div>

                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img2.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index2.html" target="_blank">Multi Page</a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index2.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index2.html">SEO & Digital Marketing 02</a>
                               </div>
                               <div class="space20"></div>
                            </div>
                          </div>
                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                              </div>
                              <div class="homemenu-btn">
                                <a class="header-btn12" href="index3.html" target="_blank">Multi Page</a>
                                <div class="space16"></div>
                                <a class="header-btn12" href="single-index3.html" target="_blank">One Page</a>
                             </div>
                             <div class="homemenu-content">
                              <a href="index3.html">SEO & Digital Marketing 03</a>
                             </div>
                             <div class="space20"></div>
                            </div>
                          </div>
                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img3.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index4.html" target="_blank">Multi Page</a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index4.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index4.html">SEO & Digital Marketing 04</a>
                               </div>
                               <div class="space20"></div>
                            </div>
                          </div>
                          <div class="images">
                            <div class="homemenu-thumb" style="margin: 0;">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img4.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index5.html" target="_blank">Multi Page</a>
                                   <div class="space16"></div>
                                  <a class="header-btn12" href="single-index5.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index5.html">SEO & Digital Marketing 05</a>
                               </div>
                               <div class="space20"></div>
                            </div>
                          </div>
                        </div>

                        <div class="all-images-menu">
                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img11.png" alt="">
                              </div>
                              <div class="text">
                                <h2>NEW</h2>
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index11.html" target="_blank">Multi Page </a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index11.html" target="_blank">One Page </a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index11.html">Staffing Agency</a>
                               </div>
                            </div>
                            <div class="space20"></div>
                          </div>

                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img12.png" alt="">
                              </div>
                              <div class="text">
                                <h2>NEW</h2>
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index12.html" target="_blank"> Multi Page </a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index12.html" target="_blank"> One Page </a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index12.html">Consulting Agency</a>
                               </div>
                            </div>
                            <div class="space20"></div>
                          </div>

                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                              </div>
                              <div class="text">
                                <h2>NEW</h2>
                              </div>
                              <div class="homemenu-btn">
                                <a class="header-btn12" href="index13.html" target="_blank">Multi Page </a>
                                <div class="space16"></div>
                                <a class="header-btn12" href="single-index13.html" target="_blank"> One Page </a>
                             </div>
                             <div class="homemenu-content">
                              <a href="index13.html">Advertising Agency</a>
                             </div>
                            </div>
                            <div class="space20"></div>
                          </div>

                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img14.png" alt="">
                              </div>
                              <div class="text">
                                <h2>NEW</h2>
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index14.html" target="_blank">Multi Page </a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index14.html" target="_blank"> One Page </a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index14.html">IT Solution Agency</a>
                               </div>
                            </div>
                            <div class="space20"></div>
                          </div>

                          <div class="images">
                            <div class="homemenu-thumb" style="margin: 0;">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img15.png" alt="">
                              </div>
                              <div class="text">
                                <h2>NEW</h2>
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index15.html" target="_blank">Multi Page </a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index15.html" target="_blank"> One Page </a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index15.html">Startup Agency</a>
                               </div>
                            </div>
                            <div class="space20"></div>
                          </div>
                        </div>

                        <div class="all-images-menu">
                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img5.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index6.html" target="_blank">Multi Page</a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index6.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index6.html">SEO & Digital Marketing 06</a>
                               </div>
                            </div>
                          </div>

                          <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img6.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index7.html" target="_blank">Multi Page</a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index7.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index7.html">SEO & Digital Marketing 07</a>
                               </div>
                            </div>
                          </div>

                        <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img7.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index8.html" target="_blank">Multi Page</a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index8.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>
                            </div>
                          </div>

                        <div class="images">
                            <div class="homemenu-thumb">
                              <div class="img1">
                              <img src="assets/img/all-images/demo-img8.png" alt="">
                              </div>
                               <div class="homemenu-btn">
                                  <a class="header-btn12" href="index9.html" target="_blank">Multi Page</a>
                                  <div class="space16"></div>
                                  <a class="header-btn12" href="single-index9.html" target="_blank">One Page</a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index9.html">SEO & Digital Marketing 09</a>
                               </div>
                            </div>
                          </div>
                        <div class="images">
                          <div class="homemenu-thumb" style="margin: 0;">
                            <div class="img1">
                            <img src="assets/img/all-images/demo-img9.png" alt="">
                            </div>
                            <div class="text">
                              <h2>HOT</h2>
                            </div>
                             <div class="homemenu-btn">
                                <a class="header-btn12" href="index10.html" target="_blank">Multi Page</a>
                                 <div class="space16"></div>
                                <a class="header-btn12" href="single-index10.html" target="_blank">One Page</a>
                             </div>
                             <div class="homemenu-content">
                              <a href="index10.html">SEO & Digital Marketing 10</a>
                             </div>
                          </div>
                        </div>
                      </div>

                      <div class="all-images-menu">
                        <div class="images">
                          <div class="space20"></div>
                          <div class="homemenu-thumb">
                            <div class="img1 comming-soon">
                            <img src="assets/img/all-images/demo-img17.png" alt="">
                            </div>
                             <div class="homemenu-content">
                              <a href="index6.html">Creative Agency</a>
                             </div>
                          </div>
                        </div>

                        <div class="images">
                          <div class="space20"></div>
                          <div class="homemenu-thumb">
                            <div class="img1 comming-soon">
                            <img src="assets/img/all-images/demo-img16.png" alt="">
                            </div>
                             <div class="homemenu-content">
                              <a href="index7.html">Digital Marketing Agency</a>
                             </div>
                          </div>
                        </div>

                        <div class="images">
                          <div class="space20"></div>
                          <div class="homemenu-thumb">
                            <div class="img1 comming-soon">
                            <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                            </div>
                           <div class="homemenu-content">
                            <a href="index8.html">Digital Marketer Agency</a>
                           </div>
                          </div>
                        </div>

                        <div class="images">
                          <div class="space20"></div>
                          <div class="homemenu-thumb">
                            <div class="img1 comming-soon">
                            <img src="assets/img/all-images/demo-img19.png" alt="">
                            </div>

                             <div class="homemenu-content">
                              <a href="index9.html">Corporate Agency</a>
                             </div>
                          </div>
                        </div>

                        <div class="images">
                          <div class="space20"></div>
                          <div class="homemenu-thumb" style="margin: 0;">
                            <div class="img1 comming-soon">
                            <img src="assets/img/all-images/demo-img20.png" alt="">
                            </div>
                             <div class="homemenu-content">
                              <a href="index10.html">Coming Soon</a>
                             </div>
                          </div>
                        </div>
                      </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>

              <div class="btn-area">
                <a href="contact.html" class="header-btn6">GET IN TOUCH</a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder4 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo2.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar4">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo2.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
  <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="404-5.html">Service One</a></li>
          <li><a href="404-6.html">Service Left</a></li>
          <li><a href="404-7.html">Service Right</a></li>
          <li><a href="404-8.html">Service Single</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="404-9.html">Case Study Left</a></li>
          <li><a href="404-10.html">Case Study Right</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn6">Get Started</a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="hero4-section-area">
    <div class="container">
        <div class="row">
            <div class="col-lg-8 m-auto">
                <div class="hero4-header text-center heading7">
                    <img src="assets/img/elements/plus.png" alt="" class="plus keyframe5">
                    <h5 data-aos="fade-up" data-aos-duration="800"><img src="assets/img/icons/logo-icons3.svg" alt="">Top #1 SEO & Marketing Agency</h5>
                    <h1 class="text-anime-style-1">Drive Your Business Forward With Our Expert <img src="assets/img/all-images/header-pera1.png" alt=""><span>Digital Marketing <img src="assets/img/elements/line-img1.png" alt=""></span> Solutions</h1>
                    <div class="space20"></div>
                    <p data-aos="fade-up" data-aos-duration="1000">Welcome to SEOC where we specialize in revolutionizing your online <br class="d-lg-block d-none"> presence through expert SEO and digital marketing solutions. </p>
                    <div class="btn-area1" data-aos="fade-up" data-aos-duration="1200">
                        <a href="contact.html" class="header-btn6">START RANKING NOW</a>
                        <a href="contact.html" class="header-btn7">GET STARTED NOW</a>
                    </div>
                </div>
            </div>
            <div class="space60"></div>
            <div class="col-lg-12">
                <div class="header-images-area">
                    <div class="bg1">
                        <img src="assets/img/bg/header-bg4.png" alt="">
                    </div>
                    <div class="img1" data-aos="zoom-in" data-aos-duration="1200">
                        <img src="assets/img/all-images/header-img7.png" alt="" class="header-img7" data-aos="zoom-in" data-aos-duration="1000">
                    </div>
                    <div class="img2">
                        <img src="assets/img/all-images/header-img6.png" alt="" class="header-img6 aniamtion-key-2" data-aos="fade-right" data-aos-duration="1000">
                        <img src="assets/img/elements/elements10.png" alt="" class="elements10">
                    </div>
                    <div class="img3">
                        <img src="assets/img/all-images/header-img4.png" alt="" class="header-img6 aniamtion-key-1" data-aos="fade-right" data-aos-duration="1200">
                        <img src="assets/img/elements/elements9.png" alt="" class="elements10">
                    </div>
                    <div class="img4">
                        <img src="assets/img/all-images/header-img5.png" alt="" class="header-img6 aniamtion-key-2"  data-aos="fade-left" data-aos-duration="1000">
                        <img src="assets/img/icons/sound-icons2.svg" alt="" class="elements10 aniamtion-key-5">
                    </div>
                    <div class="content" data-aos="fade-left" data-aos-duration="1200">
                        <ul>
                            <li><i class="fa-solid fa-star"></i></li>
                            <li><i class="fa-solid fa-star"></i></li>
                            <li><i class="fa-solid fa-star"></i></li>
                            <li><i class="fa-solid fa-star"></i></li>
                            <li><i class="fa-solid fa-star"></i></li>
                        </ul>
                        <p>“We are dedicated, reliable <br> & assigned to grow your business.”</p>
                        <span><img src="assets/img/icons/star1.svg" alt="">CEO & Founder</span>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->

<!--===== ABOUT AREA STARTS =======-->
<div class="about4-section-area sp6">
    <div class="container">
      <div class="row align-items-center">
        <div class="col-lg-4">
          <div class="about-images">
           <figure class="image-anime reveal">
            <img src="assets/img/all-images/about-img1.png" alt="">
           </figure>
            <img src="assets/img/elements/star1.png" alt="" class="star1 keyframe5">
          </div>
        </div>
        <div class="col-lg-5">
          <div class="about-content-area heading8">
            <div class="arrow-circle">
            <a href="about.html">
              <img src="assets/img/elements/elements4.png" alt="" class="elements4 keyframe5">
              <img src="assets/img/icons/arrow.svg" alt="" class="arrow">
            </a>
            </div>
            <br>
            <h5><img src="assets/img/icons/logo-icons3.svg" alt="">About SEOC</h5>
            <h2 class="text-anime-style-2">Comprehensive SEO & <span>Digital Marketing <img src="assets/img/elements/line-img2.png" alt=""></span> Solutions.</h2>
            <p data-aos="fade-up" data-aos-duration="1000">Welcome to SEOC your trusted partner for comprehensive SEO and digital marketing solutions. With our proven expertise and innovative strategies the digital landscape.</p>
            <div class="btn-area" data-aos="fade-up" data-aos-duration="1200">
              <a href="about.html" class="header-btn6">LEARN MORE</a>
            </div>
          </div>
        </div>
        <div class="col-lg-3">
          <div class="about-auhtor-images">
            <img src="assets/img/elements/elements5.png" alt="" class="elements5 keyframe5">
            <figure class="image-anime reveal">
              <img src="assets/img/all-images/about-img2.png" alt="">
             </figure>
          </div>
        </div>
      </div>
    </div>
  </div>
<!--===== ABOUT AREA ENDS =======-->

<!--===== SERVICE AREA STARTS =======-->
<div class="service4-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="service4-header heading8 text-center">
                    <h5 data-aos="fade-up" data-aos-duration="1000"><img src="assets/img/icons/logo-icons3.svg" alt="">Our Service</h5>
                    <h2 class="text-anime-style-1">Our Comprehensive Suite Of Digital Marketing <span>Services. <img src="assets/img/elements/line-img2.png" alt=""></span></h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12">
                <div class="service-auhtor-boxes-area">
                    <div class="bg-images">
                        <div class="img1">
                            <img src="assets/img/bg/service-bg1.png" alt="" class="pulse-border">
                        </div>
                        <div class="icons" data-aos="zoom-in" data-aos-duration="1000">
                            <img src="assets/img/icons/logo-icons4.svg" alt="">
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-5 col-md-6" data-aos="zoom-out" data-aos-duration="1000">
                            <div class="service-box-area">
                                <div class="icons-area">
                                    <div class="icons">
                                        <img src="assets/img/icons/service-icon11.svg" alt="">
                                    </div>
                                    <div class="number">
                                        <h4>01</h4>
                                    </div>
                                </div>
                                <div class="content-area">
                                    <a href="service1.html">Search Engine Optimization</a>
                                    <p>Our team of experts will optimize your site's on-page elements, create high-quality content, and build authoritative backlinks to boost your rankings  attract.</p>
                                    <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 d-lg-block d-none"></div>

                        <div class="col-lg-5 col-md-6" data-aos="zoom-out" data-aos-duration="1200">
                            <div class="service-box-area">
                                <div class="icons-area">
                                    <div class="icons">
                                        <img src="assets/img/icons/service-icon12.svg" alt="">
                                    </div>
                                    <div class="number">
                                        <h4>02</h4>
                                    </div>
                                </div>
                                <div class="content-area">
                                    <a href="service1.html">Pay-Per-Click(PPC) Advertising</a>
                                    <p>Maximize your ROI with strategic PPC campaigns tailored to your business objectives. Whether you're looking to increase brand awareness,</p>
                                    <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                                </div>
                            </div>
                        </div>
                        <div class="space100 d-md-block d-none"></div>
                        <div class="space100"></div>
                        <div class="col-lg-5 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                            <div class="service-box-area">
                                <div class="icons-area">
                                    <div class="icons">
                                        <img src="assets/img/icons/service-icon13.svg" alt="">
                                    </div>
                                    <div class="number">
                                        <h4>03</h4>
                                    </div>
                                </div>
                                <div class="content-area">
                                    <a href="service1.html">Social Media Marketing</a>
                                    <p>Engage with your audience, build brand loyalty, drive conversions through strategic social media marketing. From content creation and community management. </p>
                                    <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 d-lg-block d-none"></div>

                        <div class="col-lg-5 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                            <div class="service-box-area">
                                <div class="icons-area">
                                    <div class="icons">
                                        <img src="assets/img/icons/service-icon14.svg" alt="">
                                    </div>
                                    <div class="number">
                                        <h4>04</h4>
                                    </div>
                                </div>
                                <div class="content-area">
                                    <a href="service1.html">Content Marketing</a>
                                    <p>Nurture leads, drive conversions, and build customer loyalty with targeted email marketing campaigns. From automated drip campaigns & personalized newsletters. </p>
                                    <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                                </div>
                            </div>
                        </div>

                        <div class="col-lg-12">
                            <div class="space50 d-md-block d-none"></div>
                            <div class="btn-area1 text-center" data-aos="fade-up" data-aos-duration="1200">
                                <a href="service1.html" class="header-btn6">VIEW MORE SERVICES</a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== SERVICE AREA ENDS =======-->

<!--===== CASE AREA STARTS =======-->
<div class="case4-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="case4-header heading8 text-center">
                    <h5 data-aos="fade-up" data-aos-duration="1000"><img src="assets/img/icons/logo-icons3.svg" alt="">Case Study</h5>
                    <h2 class="text-anime-style-1">Our Handpicked Digital Marketing <span>Case Study <img src="assets/img/elements/line-img2.png" alt=""></span></h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12" data-aos="fade-up" data-aos-duration="1200">
                <div class="cs_case_study_1_list">
                  <div class="cs_case_study cs_style_1 cs_hover_active active">
                    <a href="case-single.html" class="cs_case_study_thumb cs_bg_filed" data-src="assets/img/all-images/case-img1.png"></a>
                    <div class="content-area1">
                      <a href="case-single.html">Website  Design & Development</a>
                    </div>
                    <div class="content-area">
                      <img src="assets/img/icons/case-icon1.svg" alt="">
                      <div class="space16"></div>
                      <a href="case-single.html">Website  Design & Development </a>
                      <p>Digital Art. Illustrations</p>
                    </div>
                  </div>
                  <div class="cs_case_study cs_style_1 cs_hover_active">
                    <a href="case-single.html" class="cs_case_study_thumb cs_case_study_thumb2 cs_bg_filed" data-src="assets/img/all-images/case-img2.png"></a>
                    <div class="content-area1">
                      <a href="case-single.html">SEO</a>
                    </div>
                    <div class="content-area">
                      <img src="assets/img/icons/case-icon1.svg" alt="">
                      <div class="space16"></div>
                      <a href="case-single.html">SEO</a>
                      <p>Digital Art. Illustrations</p>
                    </div>
                  </div>
                  <div class="cs_case_study cs_style_1 cs_hover_active">
                    <a href="case-single.html" class="cs_case_study_thumb cs_case_study_thumb3 cs_bg_filed" data-src="assets/img/all-images/case-img3.png"></a>
                    <div class="content-area1">
                      <a href="case-single.html">PPC Advertising</a>
                    </div>
                    <div class="content-area">
                      <img src="assets/img/icons/case-icon1.svg" alt="">
                      <div class="space16"></div>
                      <a href="case-single.html">PPC Advertising</a>
                      <p>Digital Art. Illustrations</p>
                    </div>
                  </div>
                  <div class="cs_case_study cs_style_1 cs_hover_active">
                    <a href="case-single.html" class="cs_case_study_thumb cs_case_study_thumb4 cs_bg_filed" data-src="assets/img/all-images/case-img4.png"></a>
                    <div class="content-area1">
                      <a href="case-single.html">Social Media Marketing</a>
                    </div>
                    <div class="content-area">
                        <img src="assets/img/icons/case-icon1.svg" alt="">
                        <div class="space16"></div>
                      <a href="case-single.html">Social Media Marketing</a>
                      <p>Digital Art. Illustrations</p>
                    </div>
                  </div>
                </div>
                <div class="space60 d-lg-block d-none"></div>
                <div class="space34 d-lg-none d-block"></div>
                <div class="btn-area1 text-center" data-aos="fade-up" data-aos-duration="1200">
                    <a href="case.html" class="header-btn6">VIEW MORE CASE STUDY</a>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== CASE AREA ENDS =======-->

<!--===== WORK AREA STARTS =======-->
<div class="works4-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-4">
                <div class="works4-header heading8">
                    <h5 data-aos="fade-up" data-aos-duration="800"><img src="assets/img/icons/logo-icons3.svg" alt="">Work Process</h5>
                    <h2 class="text-anime-style-1">SEOC Your Path to SEO & Digital <span>Marketing Success <img src="assets/img/elements/line-img1.png" alt=""></span></h2>
                    <div class="space10 d-lg-block d-none"></div>
                    <p data-aos="fade-up" data-aos-duration="1000">From increasing your website's visibility on search engines to engaging with your audience on social media,</p>
                    <div class="space32"></div>
                    <div class="btn-area1" data-aos="fade-up" data-aos-duration="1200">
                        <a href="case.html" class="header-btn6">LEARN MORE</a>
                    </div>
                </div>
            </div>
            <div class="col-lg-1"></div>
            <div class="col-lg-7">
                <div class="case-images" data-aos="zoom-in" data-aos-duration="1000">
                    <figure class="image-anime reveal">
                        <img src="assets/img/all-images/case-img8.png" alt="">
                    </figure>
                </div>
            </div>
            <div class="space50"></div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="works-author-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/works-icon4.svg" alt="">
                    </div>
                    <div class="space24"></div>
                    <div class="content-area">
                        <a href="case-single.html">Strategy Development</a>
                        <p>Based on our findings, we develop <br class="d-lg-block d-none">  customized digital marketing strategy <br class="d-lg-block d-none"> tailored objective.</p>
                        <a href="case-single.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="works-author-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/works-icon5.svg" alt="">
                    </div>
                    <div class="space24"></div>
                    <div class="content-area">
                        <a href="case-single.html">Monitoring & Optimization</a>
                        <p>We believe in the power of data-driven <br class="d-lg-block d-none"> decision-making. Throughout the <br class="d-lg-block d-none"> campaign,.</p>
                        <a href="case-single.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="works-author-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/works-icon6.svg" alt="">
                    </div>
                    <div class="space24"></div>
                    <div class="content-area">
                        <a href="case-single.html">Continuous Improvement</a>
                        <p>Digital marketing is an ever-evolving field, <br class="d-lg-block d-none"> and we're committed to staying ahead of <br class="d-lg-block d-none"> the SEOC curve.</p>
                        <a href="case-single.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== WORK AREA ENDS =======-->

<!--===== PRICING AREA STARTS =======-->
<div class="pricing-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-4 m-auto">
                <div class="pricing-header heading8 text-center">
                    <h5 data-aos="fade-up" data-aos-duration="1000"><img src="assets/img/icons/logo-icons3.svg" alt="">Pricing & Plan</h5>
                    <h2 class="text-anime-style-1">SEOC <span>Pricing Plan <img src="assets/img/elements/line-img2.png" alt=""></span></h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="flip-right" data-aos-duration="800">
                <div class="pricing-boxarea">
                    <h4>Basic Plan - Starter</h4>
                    <p>Our SEO and Digital Marketing agency <br class="d-lg-block d-none"> offers a range of pricing plans tailored</p>
                    <h1>$999 <span>/monthly</span></h1>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="pricing.html" class="header-btn6">CHOOSE YOUR PLAN</a>
                    </div>
                    <div class="space32"></div>
                    <div class="list-area">
                        <h5>Service Include:</h5>
                        <ul>
                            <li><img src="assets/img/icons/check2.svg" alt="" class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">Keyword Research</li>
                            <li><img src="assets/img/icons/check2.svg" alt=""  class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">One Page Optimization</li>
                            <li><img src="assets/img/icons/check2.svg" alt=""  class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">Basic Analytics Reporting</li>
                        </ul>
                    </div>
                    <div class="space24"></div>
                    <p class="pera">Small businesses or startups looking to <br class="d-lg-block d-none"> establish their online presence.</p>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="flip-left" data-aos-duration="1000">
                <div class="pricing-boxarea active">
                    <h4>Standard Plan - Growth</h4>
                    <p>Our SEO and Digital Marketing agency <br class="d-lg-block d-none"> offers a range of pricing plans tailored</p>
                    <h1>$1999 <span>/monthly</span></h1>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="pricing.html" class="header-btn6">CHOOSE YOUR PLAN</a>
                    </div>
                    <div class="space32"></div>
                    <div class="list-area">
                        <h5>Service Include:</h5>
                        <ul>
                            <li><img src="assets/img/icons/check2.svg" alt="" class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">Keyword Research</li>
                            <li><img src="assets/img/icons/check2.svg" alt=""  class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">One Page Optimization</li>
                            <li><img src="assets/img/icons/check2.svg" alt=""  class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">Basic Analytics Reporting</li>
                        </ul>
                    </div>
                    <div class="space24"></div>
                    <p class="pera">Small businesses or startups looking to <br class="d-lg-block d-none"> establish their online presence.</p>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="flip-right" data-aos-duration="1200">
                <div class="pricing-boxarea">
                    <h4>Premium Plan - Pro</h4>
                    <p>Our SEO and Digital Marketing agency <br class="d-lg-block d-none"> offers a range of pricing plans tailored</p>
                    <h1>$2999 <span>/monthly</span></h1>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="pricing.html" class="header-btn6">CHOOSE YOUR PLAN</a>
                    </div>
                    <div class="space32"></div>
                    <div class="list-area">
                        <h5>Service Include:</h5>
                        <ul>
                            <li><img src="assets/img/icons/check2.svg" alt="" class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">Keyword Research</li>
                            <li><img src="assets/img/icons/check2.svg" alt=""  class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">One Page Optimization</li>
                            <li><img src="assets/img/icons/check2.svg" alt=""  class="check2"><img src="assets/img/icons/check3.svg" alt="" class="check3">Basic Analytics Reporting</li>
                        </ul>
                    </div>
                    <div class="space24"></div>
                    <p class="pera">Small businesses or startups looking to <br class="d-lg-block d-none"> establish their online presence.</p>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== PRICING AREA ENDS =======-->


<!--===== TESTIMONIAL AREA STARTS =======-->
<div class="testimonial4-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-5 m-auto">
                <div class="testimonia4-header text-center heading8">
                    <h5 data-aos="fade-up" data-aos-duration="1000"><img src="assets/img/icons/logo-icons3.svg" alt="">Testimonials</h5>
                    <h2 class="text-anime-style-1">“What Our <span>Client Say” <img src="assets/img/elements/line-img2.png" alt=""></span> </h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12" data-aos="zoom-out" data-aos-duration="1200">
                <div class="testimonial4-slider-area owl-carousel">
                    <div class="testimonial-boxarea">
                        <img src="assets/img/icons/quito2.svg" alt="" class="quito">
                        <p>Working with SEOC has been a game-changer for our business. Their strategic approach to SEO  digital marketing has significantly increased our online visibility and lead generation.”</p>
                        <div class="space48"></div>
                        <div class="auhtor-logo">
                            <div class="text">
                                <a href="team.html">Sarah L.</a>
                                <ul>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                </ul>
                            </div>
                            <div class="logo">
                                <img src="assets/img/icons/google1.svg" alt="">
                            </div>
                        </div>
                    </div>

                    <div class="testimonial-boxarea">
                        <img src="assets/img/icons/quito2.svg" alt="" class="quito">
                        <p>“We've been partnering with SEOC for over a year now, and the results speak for themselves. Their comprehensive digital marketing solutions have helped us achieve measurable growth."</p>
                        <div class="space48"></div>
                        <div class="auhtor-logo">
                            <div class="text">
                                <a href="team.html">David M.</a>
                                <ul>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                </ul>
                            </div>
                            <div class="logo">
                                <img src="assets/img/icons/google1.svg" alt="">
                            </div>
                        </div>
                    </div>

                    <div class="testimonial-boxarea">
                        <img src="assets/img/icons/quito2.svg" alt="" class="quito">
                        <p>"As a startup, we needed a digital marketing partner that could understand our unique needs and deliver cost-effective solutions. SEOC has been that partner for us.”</p>
                        <div class="space48"></div>
                        <div class="auhtor-logo">
                            <div class="text">
                                <a href="team.html">Emily R.</a>
                                <ul>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                </ul>
                            </div>
                            <div class="logo">
                                <img src="assets/img/icons/google1.svg" alt="">
                            </div>
                        </div>
                    </div>

                    <div class="testimonial-boxarea">
                        <img src="assets/img/icons/quito2.svg" alt="" class="quito">
                        <p>Working with SEOC has been a game-changer for our business. Their strategic approach to SEO  digital marketing has significantly increased our online visibility and lead generation.”</p>
                        <div class="space48"></div>
                        <div class="auhtor-logo">
                            <div class="text">
                                <a href="team.html">Sarah L.</a>
                                <ul>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                </ul>
                            </div>
                            <div class="logo">
                                <img src="assets/img/icons/google1.svg" alt="">
                            </div>
                        </div>
                    </div>

                    <div class="testimonial-boxarea">
                        <img src="assets/img/icons/quito2.svg" alt="" class="quito">
                        <p>“We've been partnering with SEOC for over a year now, and the results speak for themselves. Their comprehensive digital marketing solutions have helped us achieve measurable growth."</p>
                        <div class="space48"></div>
                        <div class="auhtor-logo">
                            <div class="text">
                                <a href="team.html">David M.</a>
                                <ul>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                </ul>
                            </div>
                            <div class="logo">
                                <img src="assets/img/icons/google1.svg" alt="">
                            </div>
                        </div>
                    </div>

                    <div class="testimonial-boxarea">
                        <img src="assets/img/icons/quito2.svg" alt="" class="quito">
                        <p>"As a startup, we needed a digital marketing partner that could understand our unique needs and deliver cost-effective solutions. SEOC has been that partner for us.”</p>
                        <div class="space48"></div>
                        <div class="auhtor-logo">
                            <div class="text">
                                <a href="team.html">Emily R.</a>
                                <ul>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                    <li><i class="fa-solid fa-star"></i></li>
                                </ul>
                            </div>
                            <div class="logo">
                                <img src="assets/img/icons/google1.svg" alt="">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== TESTIMONIAL AREA ENDS =======-->

<!--===== BLOG AREA STARTS =======-->
<div class="blog4-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-9 m-auto">
                <div class="blog4-header text-center heading8">
                    <h5 data-aos="fade-up" data-aos-duration="1000"><img src="assets/img/icons/logo-icons3.svg" alt="">Blog & News</h5>
                    <h2 class="text-anime-style-1">"Insights & Updates <span>Digital Marketing <img src="assets/img/elements/line-img1.png" alt=""></span> </h2>
                </div>
            </div>
        </div>
        <div class="row">
          <div class="col-lg-6 col-md-6" data-aos="zoom-out" data-aos-duration="1000">
            <div class="blog-auhtor-boxarea">
              <div class="blog-content-area">
                <ul>
                  <li><a href="#"><i class="fa-regular fa-circle-user"></i>John Doe</a></li>
                  <li><a href="#"><i class="fa-solid fa-calendar-days"></i> 12 Feb 2024</a></li>
                </ul>
                <div class="space16"></div>
                <a href="blog-single.html">Social Media Marketing Strategies to Drive Engagement and Conversions</a>
                <div class="space16"></div>
                <p>Discover the latest trends and best practices in social media marketing with our comprehensive guide. Learn how to leverage different.</p>
                <a href="blog-single.html" class="readmore">Learn More<i class="fa-solid fa-arrow-right"></i></a>
              </div>
              <div class="space24"></div>
              <div class="img1">
               <figure class="image-anime">
                <img src="assets/img/all-images/blog-img6.png" alt="">
               </figure>
              </div>
            </div>
          </div>

          <div class="col-lg-6 col-md-6" data-aos="zoom-out" data-aos-duration="1200">
            <div class="blog-auhtor-boxarea">
              <div class="blog-content-area">
                <ul>
                  <li><a href="#"><i class="fa-regular fa-circle-user"></i>John Doe</a></li>
                  <li><a href="#"><i class="fa-solid fa-calendar-days"></i> 12 Feb 2024</a></li>
                </ul>
                <div class="space16"></div>
                <a href="blog-single.html">Content Marketing 101: How to Create Compelling Content That Converts</a>
                <div class="space16"></div>
                <p>Unlock the secrets to successful content marketing with our expert tips and strategies. Whether you're a beginner or a seasoned marketer. </p>
                <a href="blog-single.html" class="readmore">Learn More<i class="fa-solid fa-arrow-right"></i></a>
              </div>
              <div class="space24"></div>
              <div class="img1">
               <figure class="image-anime">
                <img src="assets/img/all-images/blog-img7.png" alt="">
               </figure>
              </div>
            </div>
          </div>
        </div>
    </div>
</div>
<!--===== BLOG AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta4-section-area">
  <img src="assets/img/bg/cta-bg5.png" alt="" class="cta-bg1 aniamtion-key-2">
  <img src="assets/img/bg/cta-bg4.png" alt="" class="cta-bg2 aniamtion-key-1">
    <div class="container">
      <div class="row">
        <div class="col-lg-12 m-auto">  
          <div class="cta-header-area text-center sp4 heading2">
            <h2 class="text-anime-style-1">Ready To Take Your SEO To <br class="d-md-block d-none"> The Next Level</h2>
            <p data-aos="fade-up" data-aos-duration="1000">Effective SEO strategies not only elevate a website's visibility but also drive <br class="d-md-block d-none"> targeted traffic, enhance user experience,</p>
            <div class="btn-area text-center" data-aos="fade-up" data-aos-duration="1200">
              <a href="contact.html" class="header-btn7"> GET FREE CONSULTATION</a>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
  <!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer4-section-area">
    <div class="container">
      <div class="row">
        <div class="col-lg-3 col-md-6">
          <div class="footer-logo-area">
            <img src="assets/img/logo/logo5.png" alt="">
            <p>By optimizing content, leveraging relevant keywords, and adhering to best practices, businesses can secure prominent position (SEO)</p>
            <ul>
              <li><a href="#"><img src="assets/img/icons/facebook4.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/instagram4.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/linkedin4.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/twitter3.svg" alt=""></a></li>
            </ul>
          </div>
        </div>
  
        <div class="col-lg-2 col-md-6">
          <div class="footer-logo-area1">
            <h3>About Link</h3>
            <ul>
              <li><a href="blog.html">Our Blog</a></li>
            <li><a href="about.html">About Us</a></li>
            <li><a href="service1.html">Services</a></li>
            <li><a href="case.html">Marketing</a></li>
            <li><a href="testimonials.html">Testimonials</a></li>
            <li><a href="contact.html">Contact Us</a></li>
            </ul>
          </div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="footer-logo-area2">
            <h3>Get in touch</h3>
            <ul>
              <li><a href="404-4.html"><img src="assets/img/icons/email.svg" alt=""><span>Infoseoc@gmail.com</span></a></li>
              <li><a href="#"><img src="assets/img/icons/location.svg" alt=""><span>8708 Technology Forest <br class="d-lg-block d-none"> Pl Suite 125 -G, The <br class="d-lg-block d-none"> Woodlands, TX 773</span></a></li>
              <li><a href="tel:123-456-7890"><img src="assets/img/icons/phone.svg" alt=""><span>123-456-7890</span></a></li>
            </ul>
          </div>
        </div>
        <div class="col-lg-4 col-md-6">
          <div class="footer-logo-area3">
            <h3>Subscribe Our Newsletter</h3>
            <form action="#">
              <input type="text" placeholder="Enter Your email">
              <button class="header-btn8"> Subscribe</button>
            </form>
          </div>
        </div>
      </div>
      <div class="space80 d-lg-block d-none"></div>
      <div class="space40 d-lg-none d-block"></div>
      <div class="row">
        <div class="col-lg-12">
          <div class="copyright-area">
            <div class="pera">
              <p>ⓒCopyright 2024 SEOC . All rights reserved</p>
            </div>
            <ul>
              <li><a href="#">Terms & Conditions</a></li>
              <li><a href="#" class="m-0"> Privacy Policy </a></li>
            </ul>
          </div>
        </div>
      </div>
    </div>
  </div>
<!--===== FOOTER AREA ENDS =======-->


<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/index6.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:41:25 GMT -->
</html>